@@ -31,6 +31,7 @@ async def sync_preseem_model(preseem_model,
                              system=None,
                              delete=False,
                              noact=False,
+                             throttle=None,
                              verbose=0):
     """
     Update the Preseem model to keep it in sync with metadata references.
@@ -88,9 +89,29 @@ async def sync_preseem_model(preseem_model,
                     else:
                         # Multiple elements have this IP; find the best one.
                         # Prefer a polled one; if there are multiple polled
-                        # make a deterministic choice by order of poller hash.
-                        el = sorted(el, key=lambda x: x.poller_hash or b'')
-                        elem = el[-1]
+                        # make a deterministic choice by status, then by
+                        # order of poller hash.
+                        polled_el = [x for x in el if x.poller_hash]
+                        if polled_el:
+                            if len(polled_el) == 1:
+                                elem = polled_el[0]
+                            else:
+                                polled_online = [
+                                    x for x in polled_el if x.status in (
+                                        ElementStatus.ELEMENT_STATUS_ONLINE,
+                                        ElementStatus.ELEMENT_STATUS_WARNING,
+                                        ElementStatus.ELEMENT_STATUS_ERROR)
+                                ]
+                                if polled_online:
+                                    elem = sorted(
+                                        polled_online,
+                                        key=lambda x: x.poller_hash)[-1]
+                                else:
+                                    elem = sorted(
+                                        polled_el,
+                                        key=lambda x: x.poller_hash)[-1]
+                        else:
+                            elem = sorted(el, key=lambda x: x.uuid)[0]
                     if elem:
                         linked_elems.add(elem.uuid)
                 ap_elem[ap_ref.value] = elem
@@ -166,6 +187,8 @@ async def sync_preseem_model(preseem_model,
                     await nm_model.set_ref(
                         NetworkMetadataReference('ap_model', ap_ref.value,
                                                  {'uuid': elem_uuid}))
+                if throttle:
+                    break  # STM-7295 only do an action per call
 
         # Cleanup elements that were referencing a billing entity but are no longer.
         for elem in model_elems.values():
